@@ -1,7 +1,7 @@
 import matplotlib
 from matplotlib.colors import LinearSegmentedColormap
-from albumpl.cmap import register_all
-# from albumpl import cmap
+# from albumpl.cmap import register_all
+from albumpl import cmap
 
 class Vividict(dict):
 	## with thanks to https://stackoverflow.com/a/24089632
@@ -90,7 +90,7 @@ covers['ChutesTooNarrow']['cmap'] = ['#aada77', '#fffffd', '#8dcfdf']
 covers['ChutesTooNarrow']['ncolors'] = 6
 covers['ChutesTooNarrow']['maptype'] = "diverging"
 
-register_all()
+# register_all()
 
 ##########
 # * * * *
